changeset 5706:b4e995417c9b

Rename local variable 'not'. Needed when CC=g++.
author Bruno Haible <bruno@clisp.org>
date Tue, 15 Mar 2005 12:00:04 +0000
parents cb1401375000
children 8cfacae7bbe5
files lib/ChangeLog lib/regex.c
diffstat 2 files changed, 17 insertions(+), 12 deletions(-) [+]
line wrap: on
line diff
--- a/lib/ChangeLog
+++ b/lib/ChangeLog
@@ -1,3 +1,8 @@
+2005-03-15  Bruno Haible  <bruno@clisp.org>
+
+	* regex.c (byte_re_match_2_internal): Rename local variable 'not' to
+	'negate'.
+
 2005-03-14  Paul Eggert  <eggert@cs.ucla.edu>
 
 	* mktime.c (TYPE_TWOS_COMPLEMENT, TYPE_ONES_COMPLEMENT,
--- a/lib/regex.c
+++ b/lib/regex.c
@@ -6277,9 +6277,9 @@
 	    uint32_t nrules;
 # endif /* _LIBC */
 #endif /* WCHAR */
-	    boolean not = (re_opcode_t) *(p - 1) == charset_not;
-
-            DEBUG_PRINT2 ("EXECUTING charset%s.\n", not ? "_not" : "");
+	    boolean negate = (re_opcode_t) *(p - 1) == charset_not;
+
+            DEBUG_PRINT2 ("EXECUTING charset%s.\n", negate ? "_not" : "");
 	    PREFETCH ();
 	    c = TRANSLATE (*d); /* The character to match.  */
 #ifdef WCHAR
@@ -6612,20 +6612,20 @@
 	      if (c == *workp)
 		goto char_set_matched;
 
-	    not = !not;
+	    negate = !negate;
 
 	  char_set_matched:
-	    if (not) goto fail;
+	    if (negate) goto fail;
 #else
             /* Cast to `unsigned' instead of `unsigned char' in case the
                bit list is a full 32 bytes long.  */
 	    if (c < (unsigned) (*p * BYTEWIDTH)
 		&& p[1 + c / BYTEWIDTH] & (1 << (c % BYTEWIDTH)))
-	      not = !not;
+	      negate = !negate;
 
 	    p += 1 + *p;
 
-	    if (!not) goto fail;
+	    if (!negate) goto fail;
 #undef WORK_BUFFER_SIZE
 #endif /* WCHAR */
 	    SET_REGS_MATCHED ();
@@ -7125,15 +7125,15 @@
 		else if ((re_opcode_t) p1[3] == charset
 			 || (re_opcode_t) p1[3] == charset_not)
 		  {
-		    int not = (re_opcode_t) p1[3] == charset_not;
+		    int negate = (re_opcode_t) p1[3] == charset_not;
 
 		    if (c < (unsigned) (p1[4] * BYTEWIDTH)
 			&& p1[5 + c / BYTEWIDTH] & (1 << (c % BYTEWIDTH)))
-		      not = !not;
-
-                    /* `not' is equal to 1 if c would match, which means
+		      negate = !negate;
+
+                    /* `negate' is equal to 1 if c would match, which means
                         that we can't change to pop_failure_jump.  */
-		    if (!not)
+		    if (!negate)
                       {
   		        p[-3] = (unsigned char) pop_failure_jump;
                         DEBUG_PRINT1 ("  No match => pop_failure_jump.\n");